@@ -296,7 +296,8 @@ class OpenEuler():
     def get_openEuler_core_rpm_list(self,os_version,os_arch):
         core_src_list=self.get_core_src_list()
         core_rpm_list=[]
-        for rpm_name,src_name in self.get_openEuler_os_rpm2src(os_version,os_arch):
+        os_rpm2src=self.get_openEuler_os_rpm2src(os_version,os_arch)
+        for rpm_name,src_name in os_rpm2src.items():
             if src_name in core_src_list and rpm_name not in core_rpm_list:
                 core_rpm_list.append(rpm_name)
         return core_rpm_list
